<?php

/**
 * @file
 * Contains MailchimpSubscribe.
 */

namespace Drupal\fluxmailchimp\Plugin\Rules\Action;

//use Drupal\fluxmailchimp\Plugin\Entity\MailchimpList;
//use Drupal\fluxmailchimp\Plugin\Entity\MailchimpListInterface;
use Drupal\fluxmailchimp\Plugin\Service\MailchimpAccountInterface;
use Drupal\fluxmailchimp\Rules\RulesPluginHandlerBase;

/**
 * "Add a user to list" action.
 */
abstract class MailchimpListBase extends RulesPluginHandlerBase implements \RulesActionHandlerInterface {

  /**
   * Rules 'options list' callback for retrieving a Mailchimp list options.
   */
  public static function getListOptions($element, $name = NULL) {
    $options = array();
    if (!empty($element->settings['account']) && $account = entity_load_single('fluxservice_account', $element->settings['account'])) {
      $lists = $account->client()->getLists();
      $lists = fluxservice_entify_multiple($lists['data'], 'fluxmailchimp_list', $account);

      foreach ($lists as $list) {
        $identifier = $list->getRemoteIdentifier();
        $name = $list->getName();
        $options[$identifier] = $name;
      }
    }
    return $options;
  }

  /**
   * Rules 'options list' callback for retrieving a Mailchimp list options.
   */
  public static function getFieldOptions($bundle = 'personal', $type = NULL) {
    $options = array();

    // load all the profile2 fields
    $fields = field_info_instances('profile2', $bundle);
    foreach ($fields as $name => $field) {
      if ($type == NULL || in_array($field['widget']['type'], array('options_select'))) {
        $options[$name] = $field['label'];

        if ($field['display']['default']['module'] == 'entityreference') {
          $ref_field = field_info_field($name);
          $entity = $ref_field['settings']['target_type'];
          $bundle = reset($ref_field['settings']['handler_settings']['target_bundles']);
          $related_fields = field_info_instances($entity, $bundle);
          foreach ($related_fields as $related_name => $related_field) {
            $options[$name . ':' . $related_name] = $field['label'] . ' - ' . $related_field['label'];
          }
        }
      }
    }
    return $options;
  }

  /**
   * @param $account
   * @param $list
   * @param $interests
   * @return mixed
   */
  public static function updateInterestGroups($account, $list, $interests) {
    $interest_values  = fluxservice_key_value("{$account->plugin}.lists");
    $id = $account->remote_id . ':' . $list;
    $params = $interest_values->get($id);
    if (empty($params)) {
      $params = array();
    }

    foreach ($interests as $interest) {
      if (empty($interest)) continue;

      $field = field_info_field($interest);
      $values = list_allowed_values($field);

      self::updateInterestGroupAllowedValues($account, $list, $interest, $values);

      $params['groups'][$interest] = array_keys($values);
    }

    $interest_values->set($id, $params);

    return $params['groups'];
  }

  /**
   * @param $account
   * @param $list
   * @param $interest
   * @param $values
   */
  public static function updateInterestGroupAllowedValues($account, $list, $interest, $values) {
    static $current_groups;

    if (!isset($current_groups[$list])) {
      try {
        $args = array('id' => $list);
        $current_groups[$list] = $account->client()->getInterestGroupings($args);
      }
      catch (\ZfrMailChimp\Exception\Ls\InvalidOptionException $e) {
        $current_groups[$list] = array();
      }
      catch (\Guzzle\Http\Exception\ServerErrorResponseException $e) {
        $current_groups[$list] = array();
      }
    }

    $interest_exists = FALSE;
    foreach ($current_groups[$list] as $group) {
      if ($interest == $group['name']) {
        // @todo - need to check the values are still all there.
        foreach ($values as $value => $label) {
          $found = FALSE;
          foreach ($group['groups'] as $item) {
            if ($item['name'] == $value) {
              $found = TRUE;
              break;
            }
          }
          if (!$found) {
            $args = array(
              'id' => $list,
              'group_name' => $value,
              'grouping_id' => $group['id']
            );
            $account->client()->addInterestGroup($args);
          }
        }
        $interest_exists = TRUE;
        break;
      }
    }
    if (!$interest_exists) {
      $args = array(
        'id' => $list,
        'name' => $interest,
        'type' => 'dropdown',
        'groups' => array_keys($values),
      );
      $account->client()->addInterestGrouping($args);
    }
  }

  public static function getMergeVarTag($field_name) {
    static $tags;
    if (!isset($tags)) {
      $tags = array();
    }

    $original_name = $field_name;
    if (isset($tags[$original_name])) {
      return $tags[$original_name];
    }

    $field_name = str_replace('field_', '', $field_name);
    if (strpos($field_name, ':') !== FALSE) {
      list($parent, $child) = explode(':', $field_name);
      $field_name = strtoupper(substr($parent, 0, 1)) . '_' . strtoupper(substr($child, 0, 7));
    }
    else {
      $field_name = strtoupper(substr($field_name, 0, 9));
    }

    $tag = $field_name;
    $count = 0;
    while (in_array($tag, $tags) && $count < 10) {
      $tag = $field_name . '' . $count;
      $count++;
    }

    $tags[$original_name] = $tag;
    return $tag;
  }

  /**
   * @param $account
   * @param $list
   * @param $marge_vars
   */
  public static function updateMergeVars($account, $list, $merge_vars) {
    $interest_values  = fluxservice_key_value("{$account->plugin}.list");
    $id = $account->remote_id . ':' . $list;
    $params = $interest_values->get($id);
    if (empty($params)) {
      $params = array();
    }

    foreach ($merge_vars as $var => $item) {
      if (empty($item)) continue;

      //$field = field_info_field($var);
      $item['tag'] = self::getMergeVarTag($item['tag']);
      self::updateMergeVar($account, $list, $item['tag'], $item['label']);

      $params['merge_var'][$item['tag']] = $var;
    }

    return $params['merge_var'];
  }

  public static function updateMergeVar($account, $list, $tag, $name) {
    static $current_vars;
    if (!isset($current_vars[$list])) {
      try {
        $args = array('id' => array($list));
        $current_vars[$list] = $account->client()->getListMergeVars($args);
      }
      catch (\ZfrMailChimp\Exception\Ls\InvalidOptionException $e) {
        $current_vars[$list] = array();
      }
      catch (\Guzzle\Http\Exception\ServerErrorResponseException $e) {
        $current_vars[$list] = array();
      }
    }

    $var_exists = FALSE;
    foreach ($current_vars[$list]['data'][0]['merge_vars'] as $merge_var) {
      if (empty($merge_var)) continue;

      if ($merge_var['tag'] == $tag) {
        $var_exists = TRUE;
      }
    }

    if (!$var_exists) {
      $params = array(
        'id' => $list,
        'tag' => $tag,
        'name' => $name,
        'options' => array(
          'field_type' => 'text' // @todo - hardcoded to text - support other types later.
        ),
      );
      try {
        $account->client()->addListMergeVar($params);
      }
      catch (\Exception $e) {
        error_log($e->getMessage());
      }
    }
  }
}